/**
 * @license Highcharts JS v6.1.2 (2018-08-31)
 *
 * (c) 2009-2017 Highsoft AS
 *
 * License: www.highcharts.com/license
 */


		Highcharts.theme = {
		    colors: ['#FDD089', '#FF7F79', '#A0446E', '#251535'],

		    colorAxis: {
		        maxColor: '#60042E',
		        minColor: '#FDD089'
		    },

		    plotOptions: {
		        map: {
		            nullColor: '#fefefc'
		        }
		    },

		    navigator: {
		        series: {
		            color: '#FF7F79',
		            lineColor: '#A0446E'
		        }
		    }
		};

		// Apply the theme
		Highcharts.setOptions(Highcharts.theme);

