{% if not html %}

    <!DOCTYPE html>
    <html>
    <head>
        {% include 'favicon.html' %}

        {% if options.tailwind %}
            {% if not options.no_internet %}
                <link rel="stylesheet" href="https://unpkg.com/tailwindcss@^2/dist/tailwind.min.css">
            {% else %}
                <link href="{{ request.headers.get('X-Forwarded-Prefix','') }}/templates/local/tailwind/tailwind.min.css" rel="stylesheet">
            {% endif %}
            <style>
                {% include 'css/form.css' %}
            </style>
        {% endif %}


        {% if not options.no_internet %}
            <link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.9.0/css/all.css"/>
            <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/3.7.0/animate.min.css"/>
        {% else %}
            <link rel="stylesheet" href="{{ request.headers.get('X-Forwarded-Prefix','') }}/templates/local/fontawesome/css/all.min.css"/>
            <link rel="stylesheet" href="{{ request.headers.get('X-Forwarded-Prefix','') }}/templates/local/animate.css"/>
        {% endif %}

        <style>
            {{ page_options.css }}
        </style>

        {{ page_options.head_html | safe }}

        {% if not html %}
            {% if not options.no_internet %}
                <script src="https://code.jquery.com/jquery-3.3.1.min.js"></script>
                <script src="https://cdnjs.cloudflare.com/ajax/libs/vue/2.6.11/vue.min.js"></script>
            {% else %}
                <script src="{{ request.headers.get('X-Forwarded-Prefix','') }}/templates/local/jquery.js"></script>
                <script src="{{ request.headers.get('X-Forwarded-Prefix','') }}/templates/local/vue.js"></script>
            {% endif %}
        {% endif %}

        {% if options.highcharts %}
            {% include 'highcharts.html' %}
        {% endif %}

        {% if options.aggrid %}
            {% if not options.no_internet %}
                <script src="https://unpkg.com/ag-grid-community/dist/ag-grid-community.min.js"></script>
            {% else %}
                <script src="{{ request.headers.get('X-Forwarded-Prefix','') }}/templates/local/ag-grid-community.js"></script>
            {% endif %}
        {% endif %}

        {% if options.aggrid_enterprise %}
            {% if not options.no_internet %}
                <script src="https://unpkg.com/ag-grid-enterprise/dist/ag-grid-enterprise.min.js"></script>
            {% else %}
                <script src="{{ request.headers.get('X-Forwarded-Prefix','') }}/templates/local/ag-grid-enterprise.js"></script>
            {% endif %}
        {% endif %}
    </head>


    <body style="{{ page_options.body_style }}" class="{{ page_options.body_classes }}">
    {{ page_options.body_html | safe }}
    <div id="components">

    </div>

    {% include 'main.html' %}

    </body>
    </html>
    {% else %}{{ html | safe }}
{% endif %}


